@@ -1,5 +1,4 @@
 # Django settings for unit test project.
-from utils import what_is_my_ip
 
 DEBUG = True
 
@@ -16,9 +15,6 @@ DATABASES = {
 
 SITE_ID = 1
 
-# The hostname of this testing server visible to the outside world
-HOST_NAME = what_is_my_ip()
-
 STATIC_URL = '/static/'
 
 SECRET_KEY = 'h2%uf!luks79rw^4!5%q#v2znc87g_)@^jf1og!04@&&tsf7*9'
